defaultColor method
Theme colour for line when the caller has not chosen one.
Implementation
@override
Color defaultColor(int line, ChartColors theme, int ordinal) =>
theme.sarColor;
Theme colour for line when the caller has not chosen one.
@override
Color defaultColor(int line, ChartColors theme, int ordinal) =>
theme.sarColor;